@@ -222,13 +222,14 @@ class interface(abstract_instrument_interface.abstract_interface):
         if log:
             self.logger.info(f"Setting sensitivity to {self.sensitivities[s]}  (index={s})...")
         try: 
+            s_old = self.sensitivity
             self.instrument.sensitivity = s #set sensitivity
-            self.read_sensitivity(log = log) #read again sensitivity to confirm that it changed and to make sure that combobox is updated
-            snew = self.sensitivity
-            if snew == s:
+            self.read_sensitivity(log = log) #read again sensitivity to store it into self.sensitivity and to make sure that combobox is updated
+            s_new = self.sensitivity #read new sensitivity
+            if s_new == s:
                 if log:
-                    self.logger.info(f"Sensitivity changed to {self.sensitivities[s]} (old value was {self.sensitivities[self.sensitivity]}).")
-                self.sensitivity = s
+                    self.logger.info(f"Sensitivity changed to {self.sensitivities[s]} (old value was {self.sensitivities[s_old]}).")
+                
             else:
                 self.logger.error(f"The driver did not raise any error, but it was not possible to change the sensitivity.")
         except Exception as e:
